@@ -24,6 +24,7 @@ import pmb.helpers.logging
 import pmb.helpers.pkgrel_bump
 import pmb.helpers.pmaports
 import pmb.helpers.repo
+import pmb.helpers.repo_bootstrap
 import pmb.helpers.repo_missing
 import pmb.helpers.run
 import pmb.helpers.status
@@ -33,11 +34,12 @@ import pmb.netboot
 import pmb.parse
 import pmb.qemu
 import pmb.sideload
+from argparse import Namespace
 
 
 def _parse_flavor(args, autoinstall=True):
-    """
-    Verify the flavor argument if specified, or return a default value.
+    """Verify the flavor argument if specified, or return a default value.
+
     :param autoinstall: make sure that at least one kernel flavor is installed
     """
     # Install a kernel and get its "flavor", where flavor is a pmOS-specific
@@ -109,6 +111,12 @@ def build(args):
     if src and not os.path.exists(src):
         raise RuntimeError("Invalid path specified for --src: " + src)
 
+    # Ensure repo_bootstrap is done for all arches we intend to build for
+    for package in args.packages:
+        arch_package = args.arch or pmb.build.autodetect.arch(args, package)
+        pmb.helpers.repo_bootstrap.require_bootstrap(args, arch_package,
+            f"build {package} for {arch_package}")
+
     # Build all packages
     for package in args.packages:
         arch_package = args.arch or pmb.build.autodetect.arch(args, package)
@@ -133,9 +141,7 @@ def checksum(args):
 
 
 def sideload(args):
-    arch = args.deviceinfo["arch"]
-    if args.arch:
-        arch = args.arch
+    arch = args.arch
     user = args.user
     host = args.host
     pmb.sideload.sideload(args, user, host, args.port, arch, args.install_key,
@@ -205,6 +211,7 @@ def config(args):
         pmb.config.save(args, cfg)
     elif args.value is not None:
         cfg["pmbootstrap"][args.name] = args.value
+        pmb.config.sanity_checks(args, cfg, False)
         logging.info("Config changed: " + args.name + "='" + args.value + "'")
         pmb.config.save(args, cfg)
     elif args.name:
@@ -217,6 +224,10 @@ def config(args):
     pmb.helpers.logging.disable()
 
 
+def repo_bootstrap(args):
+    pmb.helpers.repo_bootstrap.main(args)
+
+
 def repo_missing(args):
     missing = pmb.helpers.repo_missing.generate(args, args.arch, args.overview,
                                                 args.package, args.built)
@@ -245,6 +256,10 @@ def install(args):
         raise ValueError("Installation using rsync"
                         " is not currently supported on btrfs filesystem.")
 
+    pmb.helpers.repo_bootstrap.require_bootstrap(args, args.deviceinfo["arch"],
+        f"do 'pmbootstrap install' for {args.deviceinfo['arch']}"
+        " (deviceinfo_arch)")
+
     # On-device installer checks
     # Note that this can't be in the mutually exclusive group that has most of
     # the conflicting options, because then it would not work with --disk.
@@ -608,9 +623,11 @@ def lint(args):
     pmb.helpers.lint.check(args, packages)
 
 
-def status(args):
-    if not pmb.helpers.status.print_status(args, args.details):
-        sys.exit(1)
+def status(args: Namespace) -> None:
+    pmb.helpers.status.print_status(args)
+
+    # Do not print the DONE! line
+    sys.exit(0)
 
 
 def ci(args):
